==> zio-aws-apigatewayv2_2.12-5.17.116.2-sources.jar: zio/aws/apigatewayv2/model/GetModelsResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetModelsResponse(
    items: Option[Iterable[zio.aws.apigatewayv2.model.Model]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse = {
    import GetModelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelsResponse.wrap(buildAwsValue())
}
object GetModelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelsResponse =
      zio.aws.apigatewayv2.model.GetModelsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.apigatewayv2.model.Model.ReadOnly]]
    def nextToken: Option[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Model.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ) extends zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly {
    override val items
        : Option[List[zio.aws.apigatewayv2.model.Model.ReadOnly]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.Model.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ): zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-7.21.15.9-sources.jar: zio/aws/apigatewayv2/model/GetModelsResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetModelsResponse(
    items: Optional[Iterable[zio.aws.apigatewayv2.model.Model]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse = {
    import GetModelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelsResponse.wrap(buildAwsValue())
}
object GetModelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelsResponse =
      zio.aws.apigatewayv2.model.GetModelsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[List[zio.aws.apigatewayv2.model.Model.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Model.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ) extends zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.apigatewayv2.model.Model.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.apigatewayv2.model.Model.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelsResponse
  ): zio.aws.apigatewayv2.model.GetModelsResponse.ReadOnly = new Wrapper(impl)
}
